@@ -218,7 +218,7 @@ class InterfaceFileHandling:
             credential=self.sas_token
         )
 
-        os.makedirs(self.settings.download_location)
+        os.makedirs(self.settings.download_location, exist_ok=True)
         download_file_path = os.path.join(self.settings.download_location, filename)
         print("\nDownloading blob to \n\t" + download_file_path)
 
